@@ -99,11 +99,23 @@ opt until => (
     comment => 'Only display tweets written until the supplied datetime.',
     alias   => 'u',
 );
+opt new => (
+    isa     => 'Bool',
+    comment => 'Only display new tweets.',
+);
 opt me => (
     isa     => 'Bool',
     comment => 'Only display your tweets and all replies and mentions.',
     alias   => 'm',
 );
+opt pretty => (
+    isa     => 'Bool',
+    comment => 'Display tweets in a less dense way.',
+);
+opt simple => (
+    isa     => 'Bool',
+    comment => 'Display tweets line in one line.',
+);
 
 subcmd
   cmd     => 'view',
@@ -162,6 +174,14 @@ opt until => (
     comment => 'Only display tweets written until the supplied datetime.',
     alias   => 'u',
 );
+opt pretty => (
+    isa     => 'Bool',
+    comment => 'Display tweets in a less dense way.',
+);
+opt simple => (
+    isa     => 'Bool',
+    comment => 'Display tweets line in one line.',
+);
 
 subcmd
   cmd     => 'follow',
